Class: Aws::AppConfigData::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AppConfigData::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-appconfigdata/client.rb
Overview
An API client for AppConfigData. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::AppConfigData::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_latest_configuration(params = {}) ⇒ Types::GetLatestConfigurationResponse
Retrieves the latest deployed configuration.
-
#start_configuration_session(params = {}) ⇒ Types::StartConfigurationSessionResponse
Starts a configuration session used to retrieve a deployed configuration.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-appconfigdata/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
625 626 627 |
# File 'lib/aws-sdk-appconfigdata/client.rb', line 625 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
628 629 630 |
# File 'lib/aws-sdk-appconfigdata/client.rb', line 628 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 |
# File 'lib/aws-sdk-appconfigdata/client.rb', line 598 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AppConfigData') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-appconfigdata' context[:gem_version] = '1.52.0' Seahorse::Client::Request.new(handlers, context) end |
#get_latest_configuration(params = {}) ⇒ Types::GetLatestConfigurationResponse
Retrieves the latest deployed configuration. This API may return empty configuration data if the client already has the latest version. For more information about this API action and to view example CLI commands that show how to use it with the StartConfigurationSession API action, see [Retrieving the configuration] in the *AppConfig User Guide*.
Note the following important information.
* Each configuration token is only valid for one call to
`GetLatestConfiguration`. The `GetLatestConfiguration` response
includes a `NextPollConfigurationToken` that should always replace
the token used for the just-completed call in preparation for the
next one.
-
‘GetLatestConfiguration` is a priced call. For more information, see [Pricing].
[1]: docs.aws.amazon.com/appconfig/latest/userguide/appconfig-retrieving-the-configuration [2]: aws.amazon.com/systems-manager/pricing/
538 539 540 541 |
# File 'lib/aws-sdk-appconfigdata/client.rb', line 538 def get_latest_configuration(params = {}, = {}) req = build_request(:get_latest_configuration, params) req.send_request() end |
#start_configuration_session(params = {}) ⇒ Types::StartConfigurationSessionResponse
Starts a configuration session used to retrieve a deployed configuration. For more information about this API action and to view example CLI commands that show how to use it with the GetLatestConfiguration API action, see [Retrieving the configuration] in the *AppConfig User Guide*.
[1]: docs.aws.amazon.com/appconfig/latest/userguide/appconfig-retrieving-the-configuration
589 590 591 592 |
# File 'lib/aws-sdk-appconfigdata/client.rb', line 589 def start_configuration_session(params = {}, = {}) req = build_request(:start_configuration_session, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
618 619 620 |
# File 'lib/aws-sdk-appconfigdata/client.rb', line 618 def waiter_names [] end |